IconBox class

Inheritance
Available extensions

Constructors

IconBox({Key? key, int maxLines = 1, TextOverflow overflow = TextOverflow.ellipsis, TextAlign textAlign = TextAlign.start, bool reversal = false, Axis direction = Axis.horizontal, double spacing = 4, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, double? size, String? heroTag, IconData? icon, Color? background, Color? color, String? semanticLabel, TextDirection? textDirection, String? labelText, TextStyle? labelStyle, GestureTapCallback? onTap, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, double? width, double? height, Decoration? decoration, AlignmentGeometry? alignment, ImageProvider<Object>? imageProvider, Image? image, Widget? label, Widget? widget, VoidCallback? onPressed, UnifiedButtonCategory? unifiedButtonCategory, ValueChanged<bool>? onHover, ValueChanged<bool>? onFocusChange, ButtonStyle? style, FocusNode? focusNode, bool autofocus = false, MaterialStatesController? statesController, GestureLongPressCallback? onLongPress, Clip? clipBehavior})
const

Properties

alignment AlignmentGeometry?
整个组件居中
final
autofocus bool
final
background Color?
final
buildIcon List<Widget>
no setter
buildSpacing Widget
no setter
buildTitle Widget
no setter
clipBehavior Clip?
final
color Color?
iconimageProviderlabelText 颜色
final
crossAxisAlignment CrossAxisAlignment
final
decoration Decoration?
整个组件装饰器
final
direction Axis
组件水平或 垂直
final
expand SizedBox

Available on Widget, provided by the ExtensionWidget extension

no setter
expanded Expanded

Available on Widget, provided by the ExtensionWidget extension

no setter
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
整个组件宽高
final
heroTag String?
add Hero
final
icon IconData?
final
image Image?
final
imageProvider ImageProvider<Object>?
final
isChildren bool
no setter
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label Widget?
final
labelStyle TextStyle?
final
labelText String?
文字
final
mainAxisAlignment MainAxisAlignment
final
margin EdgeInsetsGeometry?
final
maxLines int
labelText显示时最大行数
final
onFocusChange ValueChanged<bool>?
final
onHover ValueChanged<bool>?
final
onLongPress GestureLongPressCallback?
final
onPressed VoidCallback?
****** UnifiedButton ****** ///
final
onTap GestureTapCallback?
整个组件点击事件
final
overflow TextOverflow
final
padding EdgeInsetsGeometry?
final
reversal bool
收尾颠倒 false
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
仅支持 iconimageProvider
final
shrink SizedBox

Available on Widget, provided by the ExtensionWidget extension

no setter
size double?
iconimageProvider 大小
final
spacing double
label或者labelText间距
final
statesController MaterialStatesController?
final
style ButtonStyle?
final
textAlign TextAlign
final
textDirection TextDirection?
final
toLoadingBuilder LoadingBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
toRoutePageBuilder RoutePageBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
toRouteTransitionsBuilder RouteTransitionsBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
toSliverBox Widget

Available on Widget, provided by the ExtensionWidget extension

no setter
toToastBuilder ToastBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
toWidgetBuilder WidgetBuilder

Available on Widget, provided by the ExtensionWidget extension

no setter
unifiedButtonCategory UnifiedButtonCategory?
final
widget Widget?
icon > image > imageProvider > widget
final
width double?
final

Methods

align({Key? key, Alignment alignment = Alignment.center, double? widthFactor, double? heightFactor}) Align

Available on Widget, provided by the ExtensionWidget extension

backdropFilter({Key? key, ImageFilter? filter, double fuzzyDegree = 4}) BackdropFilter

Available on Widget, provided by the ExtensionWidget extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildPageRoute<T>({PageRouteOptions pageRoute = const PageRouteOptions(), RoutePushStyle? pushStyle}) PageRoute<T>

Available on Widget, provided by the ExtensionWidget extension

card({Color? color, Color? shadowColor, double? elevation, ShapeBorder? shape, bool? borderOnForeground, EdgeInsetsGeometry? margin, Clip? clipBehavior, bool? semanticContainer}) Card

Available on Widget, provided by the ExtensionWidget extension

center({Key? key, double? widthFactor, double? heightFactor}) Center

Available on Widget, provided by the ExtensionWidget extension

clipOval({Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper<Rect>? clipper, Clip clipBehavior = Clip.antiAlias}) ClipOval

Available on Widget, provided by the ExtensionWidget extension

clipPath({Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper<Path>? clipper, Clip clipBehavior = Clip.antiAlias}) ClipPath

Available on Widget, provided by the ExtensionWidget extension

clipRRect({Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper<RRect>? clipper, Clip clipBehavior = Clip.antiAlias}) ClipRRect

Available on Widget, provided by the ExtensionWidget extension

color(Color color, {Key? key}) ColoredBox

Available on Widget, provided by the ExtensionWidget extension

constrainedBox(BoxConstraints constraints, {Key? key}) ConstrainedBox

Available on Widget, provided by the ExtensionWidget extension

container({Key? key, EdgeInsetsGeometry? padding, Decoration? foregroundDecoration, Matrix4? transform, BoxConstraints? constraints, Color? color, double? width, double? height, EdgeInsetsGeometry? margin, Decoration? decoration, Clip? clipBehavior, AlignmentGeometry? alignment}) Container

Available on Widget, provided by the ExtensionWidget extension

createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decoratedBox(Decoration decoration, {Key? key, DecorationPosition position = DecorationPosition.background}) DecoratedBox

Available on Widget, provided by the ExtensionWidget extension

fittedBox({Key? key, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, Clip clipBehavior = Clip.none}) FittedBox

Available on Widget, provided by the ExtensionWidget extension

flexible({Key? key, int flex = 1, FlexFit fit = FlexFit.loose}) Flexible

Available on Widget, provided by the ExtensionWidget extension

fromSize(Size size, {Key? key}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

gestureDetector({Key? key, GestureTapDownCallback? onTapDown, GestureTapUpCallback? onTapUp, GestureTapCallback? onTap, GestureTapCancelCallback? onTapCancel, GestureTapDownCallback? onSecondaryTapDown, GestureTapUpCallback? onSecondaryTapUp, GestureTapCancelCallback? onSecondaryTapCancel, GestureTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureLongPressStartCallback? onLongPressStart, GestureLongPressMoveUpdateCallback? onLongPressMoveUpdate, GestureLongPressUpCallback? onLongPressUp, GestureLongPressEndCallback? onLongPressEnd, GestureDragDownCallback? onVerticalDragDown, GestureDragStartCallback? onVerticalDragStart, GestureDragUpdateCallback? onVerticalDragUpdate, GestureDragEndCallback? onVerticalDragEnd, GestureDragCancelCallback? onVerticalDragCancel, GestureDragDownCallback? onHorizontalDragDown, GestureDragStartCallback? onHorizontalDragStart, GestureDragUpdateCallback? onHorizontalDragUpdate, GestureDragEndCallback? onHorizontalDragEnd, GestureDragCancelCallback? onHorizontalDragCancel, GestureForcePressStartCallback? onForcePressStart, GestureForcePressPeakCallback? onForcePressPeak, GestureForcePressUpdateCallback? onForcePressUpdate, GestureForcePressEndCallback? onForcePressEnd, GestureDragDownCallback? onPanDown, GestureDragStartCallback? onPanStart, GestureDragUpdateCallback? onPanUpdate, GestureDragEndCallback? onPanEnd, GestureDragCancelCallback? onPanCancel, GestureScaleStartCallback? onScaleStart, GestureScaleUpdateCallback? onScaleUpdate, GestureScaleEndCallback? onScaleEnd, HitTestBehavior? behavior, bool excludeFromSemantics = false, DragStartBehavior dragStartBehavior = DragStartBehavior.start}) GestureDetector

Available on Widget, provided by the ExtensionWidget extension

hero(Object tag, {Key? key, CreateRectTween? createRectTween, HeroFlightShuttleBuilder? flightShuttleBuilder, HeroPlaceholderBuilder? placeholderBuilder, bool transitionOnUserGestures = false}) Hero

Available on Widget, provided by the ExtensionWidget extension

limitedBox({Key? key, double maxWidth = double.infinity, double maxHeight = double.infinity}) LimitedBox

Available on Widget, provided by the ExtensionWidget extension

margin(EdgeInsetsGeometry margin, {Key? key}) Padding

Available on Widget, provided by the ExtensionWidget extension

marginAll(double margin) Widget

Available on Widget, provided by the ExtensionWidget extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the ExtensionWidget extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the ExtensionWidget extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offstage(bool offstage, {Key? key}) Offstage

Available on Widget, provided by the ExtensionWidget extension

onDoubleTap(GestureTapCallback onDoubleTap, {Key? key}) GestureDetector

Available on Widget, provided by the ExtensionWidget extension

onLongPress(GestureLongPressCallback onLongPress, {Key? key}) GestureDetector

Available on Widget, provided by the ExtensionWidget extension

onTap(GestureTapCallback? onTap, {Key? key}) GestureDetector

Available on Widget, provided by the ExtensionWidget extension

overflowBox({Key? key, Alignment alignment = Alignment.center, double? minWidth, double? maxWidth, double? minHeight, double? maxHeight}) OverflowBox

Available on Widget, provided by the ExtensionWidget extension

padding(EdgeInsetsGeometry padding) Padding

Available on Widget, provided by the ExtensionWidget extension

paddingAll(double padding) Widget

Available on Widget, provided by the ExtensionWidget extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the ExtensionWidget extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the ExtensionWidget extension

popupBottomSheet<T>({WidgetBuilder? builder, BottomSheetOptions? options}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

showModalBottomSheet 关闭 closePopup()
popupCupertinoDialog<T>({WidgetBuilder? builder, DialogOptions? options}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

Cupertino 风格的 Dialog showCupertinoDialog
popupCupertinoModal<T>({WidgetBuilder? builder, CupertinoModalPopupOptions? options}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

全屏显示 showCupertinoModalPopup
popupDialog<T>({RoutePageBuilder? builder, DialogOptions? options}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

showGeneralDialog
popupMaterialDialog<T>({WidgetBuilder? builder, DialogOptions? options}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

Material 风格的 Dialog showDialog
positioned({Key? key, double? left, double? top, double? right, double? bottom, double? width, double? height}) Positioned

Available on Widget, provided by the ExtensionWidget extension

push<T extends Object?>({bool maintainState = true, bool fullscreenDialog = false, RoutePushStyle? pushStyle, RouteSettings? settings, bool allowSnapshotting = true, bool barrierDismissible = false}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

push
pushAndRemoveUntil<T extends Object?>({RoutePushStyle? pushStyle, bool maintainState = true, bool fullscreenDialog = false, RouteSettings? settings, RoutePredicate? predicate, bool allowSnapshotting = true, bool barrierDismissible = false}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

pushAndRemoveUntil
pushReplacement<T extends Object?, TO extends Object?>({bool maintainState = true, bool fullscreenDialog = false, RoutePushStyle? pushStyle, RouteSettings? settings, bool allowSnapshotting = true, bool barrierDismissible = false, TO? result}) Future<T?>

Available on Widget, provided by the ExtensionWidgetMethod extension

pushReplacement
rotatedBox(int quarterTurns, {Key? key}) RotatedBox

Available on Widget, provided by the ExtensionWidget extension

setHeight(double height, {Key? key}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

setSize(Size size, {Key? key}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

setWidth(double width, {Key? key}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

showOverlay({bool autoOff = false}) ExtendedOverlayEntry?

Available on Widget, provided by the ExtensionWidgetMethod extension

ExtendedOverlay().showOverlay()
sizedBox({Key? key, double? width, double? height}) SizedBox

Available on Widget, provided by the ExtensionWidget extension

sizedOverflowBox(Size size, {Key? key, Alignment alignment = Alignment.center}) SizedOverflowBox

Available on Widget, provided by the ExtensionWidget extension

statusBarStyle(SystemUiOverlayStyle style) AnnotatedRegion<SystemUiOverlayStyle>

Available on Widget, provided by the ExtensionWidget extension

toDecoratorEntry({DecoratorPositioned positioned = DecoratorPositioned.outer, OverlayVisibilityMode mode = OverlayVisibilityMode.always}) DecoratorEntry

Available on Widget, provided by the ExtensionWidget extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
unconstrainedBox({Key? key, TextDirection? textDirection, Alignment alignment = Alignment.center, Axis? constrainedAxis}) UnconstrainedBox

Available on Widget, provided by the ExtensionWidget extension

universal({List<Widget>? children, Widget? child}) Widget
visibility(bool visible, {Key? key}) Visibility

Available on Widget, provided by the ExtensionWidget extension

Operators

operator ==(Object other) bool
The equality operator.
inherited